/*
 * Backend.java
 *
 * Copyright (C) 2012 Tim Marston <tim@ed.am>
 *
 * This file is part of the Import Contacts program (hereafter referred
 * to as "this program"). For more information, see
 * http://ed.am/dev/android/import-contacts
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package am.ed.importcontacts;

import am.ed.importcontacts.Importer.ContactData;


public interface Backend
{
	/**
	 * Build-up our contacts cache, using contacts on the device.
	 * @param cache the contacts cache to populate
	 */
	public void populateCache( ContactsCache cache );

	/**
	 * Delete a contact
	 * @param id of the contact to delete
	 */
	public void deleteContact( Long id );

	/**
	 * Add a contact
	 * @param name name of the new contact
	 * @return the new contact's id, or 0 on failure
	 */
	public Long addContact( String name );

	/**
	 * Add a phone number to an existing contact
	 * @param id the existing contact's id
	 * @param number the phone number
	 * @param data data about the number
	 */
	public void addContactPhone( Long id, String number,
		ContactData.PreferredDetail data );

	/**
	 * Add an email address to an existing contact
	 * @param id the existing contact's id
	 * @param email the email address
	 * @param data data about the email address
	 */
	public void addContactEmail( Long id, String email,
		ContactData.PreferredDetail data );

	/**
	 * Add an address to an existing contact
	 * @param id the existing contact's id
	 * @param address the address
	 * @param data data about the address
	 */
	public void addContactAddresses( Long id, String address,
		ContactData.TypeDetail data );

	/**
	 * Add a title and organisation to an existing contact
	 * @param id the existing contact's id
	 * @param organisation the organisation
	 * @param data data about the organisation
	 */
	public void addContactOrganisation( Long id, String organisation,
		ContactData.ExtraDetail data );
}
